coloredfloatdelegate — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- delegates »

# coloredfloatdelegate

class `camelot.view.controls.delegates.coloredfloatdelegate.` `ColoredFloatDelegate`(parent=None, minimum=-1000000000000000.0, maximum=1000000000000000.0, precision=2, reverse=False, neutral=False, unicode_format=None, **kwargs)

  Custom delegate for float values.

  > The class attribute icons is used to customize the icons displayed.

  Field attributes supported by the delegate :

  > - minimum
  > - maximum
  > - precision
  > - reverse
  > - neutral
  > - unicode_format

  By default, creates a ColoredFloatEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - precision
  > - reverse
  > - neutral
  > - option
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip
  > - prefix
  > - suffix
  > - minimum
  > - maximum
  > - single_step

  `editor`

    alias of `ColoredFloatEditor`

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- delegates »

Comments
blog comments powered by Disqus